@@ -126,13 +126,27 @@ Insert a new user
 
 =cut
 
+sub _safety_check {
+    my ($self, %opt) = @_;
+
+    unless ($opt{force}) {
+
+	my $connection = $opt{connection} || $self->connection
+	    or die "Not connected";
+
+	die "Cowardly refusing to update login user"
+	    if $self->userId eq $connection->login->userId;
+
+	die "Cowardly refusing to update system admin account for ".$self->loginName.": (pass force => 1 to override)"
+	    if ($self->_db_data->role->stringify <= 0);
+    }
+}
+
 =head2 update
 
     my $user_obj = Elive::Entity::user->retrieve([$user_id]);
 
-    $user_obj->update({fld => new_val,...}, force => 1);
-
-    $user_obj->update(role => {roleId => 1}); # make the user an app admin
+    $user_obj->update(role => 0); # make the user an app admin
     $user_obj->lastName('Smith');
     $user_obj->update(undef, force => 1);
 
@@ -145,25 +159,8 @@ As a safeguard, you'll need to pass C<force =E<gt> 1> to update:
 
 =cut
 
-sub _safety_check {
-    my ($self, %opt) = @_;
-
-    unless ($opt{force}) {
-
-	my $connection = $opt{connection} || $self->connection
-	    or die "Not connected";
-
-	die "Cowardly refusing to update SDK user"
-	    if $self->userId eq $connection->login->userId;
-
-	die "Cowardly refusing to update system admin account for ".$self->loginName.": (pass force => 1 to override)"
-	    if ($self->role->stringify <= 0);
-    }
-}
-
 sub update {
     my ($self, $data_href, %opt) = @_;
-    my %update_data = %{$data_href || {}};
 
     $self->_safety_check(%opt);
     return $self->SUPER::update( $data_href, %opt);
@@ -189,7 +186,7 @@ sub change_password {
     if (defined $new_password && $new_password ne '') {
 	$self->_safety_check(%opt);
 	$self->SUPER::update({loginPassword => $new_password},
-			     adapter => 'changePassword',
+			     command => 'changePassword',
 			     %opt,
 	    )
     }
